==> seedsui-react-5.6.60.tgz: package/lib/Picker/Modal/Head.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "caption", "disabled"],
  _excluded2 = ["visible", "caption", "disabled"],
  _excluded3 = ["caption"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import locale from "./../../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Head = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    onSubmitClick = _ref.onSubmitClick,
    onCancelClick = _ref.onCancelClick;
  // 确定和取消按钮
  var _ref2 = cancelProps || {},
    cancelVisible = _ref2.visible,
    cancelCaption = _ref2.caption,
    cancelDisabled = _ref2.disabled,
    otherCancelProps = _objectWithoutProperties(_ref2, _excluded);
  var _ref3 = submitProps || {},
    submitVisible = _ref3.visible,
    submitCaption = _ref3.caption,
    submitDisabled = _ref3.disabled,
    otherSubmitProps = _objectWithoutProperties(_ref3, _excluded2);

  // 标题
  var _ref4 = captionProps || {},
    headerCaption = _ref4.caption,
    otherCaptionProps = _objectWithoutProperties(_ref4, _excluded3);

  // 点击确定
  function handleSubmitClick(e) {
    e.stopPropagation();
    if (submitProps.onClick) submitProps.onClick(e);
    if (onSubmitClick) onSubmitClick(e);
  }

  // 点击取消
  function handleCancelClick(e) {
    e.stopPropagation();
    if (cancelProps.onClick) cancelProps.onClick(e);
    if (onCancelClick) onCancelClick(e);
  }
  return /*#__PURE__*/_jsxs("div", {
    className: "picker-header",
    ref: ref,
    children: [cancelVisible !== false && /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCancelProps), {}, {
      className: "picker-cancel".concat(otherCancelProps.className ? ' ' + otherCancelProps.className : '').concat(cancelDisabled === true ? ' disabled' : ''),
      onClick: handleCancelClick,
      children: cancelCaption || locale('取消', 'cancel')
    })), /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCaptionProps), {}, {
      className: "picker-header-title".concat(otherCaptionProps !== null && otherCaptionProps !== void 0 && otherCaptionProps.className ? ' ' + (otherCaptionProps === null || otherCaptionProps === void 0 ? void 0 : otherCaptionProps.className) : ''),
      children: headerCaption
    })), submitVisible !== false && /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherSubmitProps), {}, {
      className: "picker-submit".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : '').concat(submitDisabled === true ? ' disabled' : ''),
      onClick: handleSubmitClick,
      children: submitCaption || locale('完成', 'finish')
    }))]
  });
});
export default Head;

==> seedsui-react-5.6.70.tgz: package/lib/Picker/Modal/Head.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "caption", "disabled"],
  _excluded2 = ["visible", "caption", "disabled"],
  _excluded3 = ["caption"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import locale from "./../../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Head = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    onSubmitClick = _ref.onSubmitClick,
    onCancelClick = _ref.onCancelClick;
  // 确定和取消按钮
  var _ref2 = cancelProps || {},
    cancelVisible = _ref2.visible,
    cancelCaption = _ref2.caption,
    cancelDisabled = _ref2.disabled,
    otherCancelProps = _objectWithoutProperties(_ref2, _excluded);
  var _ref3 = submitProps || {},
    submitVisible = _ref3.visible,
    submitCaption = _ref3.caption,
    submitDisabled = _ref3.disabled,
    otherSubmitProps = _objectWithoutProperties(_ref3, _excluded2);

  // 标题
  var _ref4 = captionProps || {},
    headerCaption = _ref4.caption,
    otherCaptionProps = _objectWithoutProperties(_ref4, _excluded3);

  // 点击确定
  function handleSubmitClick(e) {
    e.stopPropagation();
    if (submitProps.onClick) submitProps.onClick(e);
    if (onSubmitClick) onSubmitClick(e);
  }

  // 点击取消
  function handleCancelClick(e) {
    e.stopPropagation();
    if (cancelProps.onClick) cancelProps.onClick(e);
    if (onCancelClick) onCancelClick(e);
  }
  return /*#__PURE__*/_jsxs("div", {
    className: "picker-header",
    ref: ref,
    children: [/*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCancelProps), {}, {
      className: "picker-close".concat(otherCancelProps.className ? ' ' + otherCancelProps.className : '').concat(cancelDisabled === true ? ' disabled' : '').concat(cancelVisible !== false ? '' : ' hidden'),
      onClick: handleCancelClick,
      children: cancelCaption || /*#__PURE__*/_jsx("div", {
        className: "picker-icon-close"
      })
    })), /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherCaptionProps), {}, {
      className: "picker-header-title".concat(otherCaptionProps !== null && otherCaptionProps !== void 0 && otherCaptionProps.className ? ' ' + (otherCaptionProps === null || otherCaptionProps === void 0 ? void 0 : otherCaptionProps.className) : ''),
      children: headerCaption
    })), /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, otherSubmitProps), {}, {
      className: "picker-submit".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : '').concat(submitDisabled === true ? ' disabled' : '').concat(submitVisible !== false ? '' : ' hidden'),
      onClick: handleSubmitClick,
      children: submitCaption || locale('完成', 'finish')
    }))]
  });
});
export default Head;
